@@ -3,7 +3,7 @@ from pbu.logger import Logger
 from pbu.time_series import TimeSeries
 from pbu.mysql_connection import MysqlConnection
 from pbu.mysql_store import AbstractMysqlStore, AbstractMysqlDocument
-from pbu.mongo_store import AbstractMongoDocument, AbstractMongoStore
+from pbu.mongo_store import AbstractMongoDocument, AbstractMongoStore, PagingInformation
 from pbu.basic_monitor import BasicMonitor
 from pbu.default_options import default_options, default_value
 from pbu.constant_listing import ConstantListing
